==> history-issue-common-1.0.0-20200720.031948-2-sources.jar: cn/gtmap/realestate/supervise/entity/JkAjxx.java <==
package cn.gtmap.realestate.supervise.entity;

import com.alibaba.fastjson.annotation.JSONField;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2020/5/23
 * @description 不动产登记历史遗留问题建库案件信息
 */
@Table(name = "JK_AJXX")
public class JkAjxx implements Serializable {
  @Id
  private String id; //主键
  private String ajbh; //案件编号
  private String wtdldm; //问题大类代码
  private String wtxldm; //问题小类代码
  private String xqmc;  //小区名称
  private String xqdz;  //小区地址
  private String js;  //件数
  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date yjjjsj; //预计解决时间
  private String jjcs; //解决措施
  private String jjzt; //解决状态
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date cjsj;  //创建时间
  private String cjr;  //创建人
  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date yjjbjsj; //已解决编辑时间
  private String yjjbjr; //已解决编辑人
  private String xzqdm; //行政区代码
  private String ajms; //案件描述
  private String bz; //备注


  public String getId() {
    return id;
  }

  public void setId(String id) {
    this.id = id;
  }


  public String getAjbh() {
    return ajbh;
  }

  public void setAjbh(String ajbh) {
    this.ajbh = ajbh;
  }


  public String getWtdldm() {
    return wtdldm;
  }

  public void setWtdldm(String wtdldm) {
    this.wtdldm = wtdldm;
  }


  public String getWtxldm() {
    return wtxldm;
  }

  public void setWtxldm(String wtxldm) {
    this.wtxldm = wtxldm;
  }


  public String getXqmc() {
    return xqmc;
  }

  public void setXqmc(String xqmc) {
    this.xqmc = xqmc;
  }


  public String getXqdz() {
    return xqdz;
  }

  public void setXqdz(String xqdz) {
    this.xqdz = xqdz;
  }


  public String getJs() {
    return js;
  }

  public void setJs(String js) {
    this.js = js;
  }

  public Date getYjjjsj() {
    return yjjjsj;
  }

  public void setYjjjsj(Date yjjjsj) {
    this.yjjjsj = yjjjsj;
  }

  public String getJjcs() {
    return jjcs;
  }

  public void setJjcs(String jjcs) {
    this.jjcs = jjcs;
  }


  public String getJjzt() {
    return jjzt;
  }

  public void setJjzt(String jjzt) {
    this.jjzt = jjzt;
  }

  public Date getCjsj() {
    return cjsj;
  }

  public void setCjsj(Date cjsj) {
    this.cjsj = cjsj;
  }

  public String getCjr() {
    return cjr;
  }

  public void setCjr(String cjr) {
    this.cjr = cjr;
  }

  public Date getYjjbjsj() {
    return yjjbjsj;
  }

  public void setYjjbjsj(Date yjjbjsj) {
    this.yjjbjsj = yjjbjsj;
  }

  public String getYjjbjr() {
    return yjjbjr;
  }

  public void setYjjbjr(String yjjbjr) {
    this.yjjbjr = yjjbjr;
  }


  public String getXzqdm() {
    return xzqdm;
  }

  public void setXzqdm(String xzqdm) {
    this.xzqdm = xzqdm;
  }

  public String getAjms() {
    return ajms;
  }

  public void setAjms(String ajms) {
    this.ajms = ajms;
  }

  public String getBz() {
    return bz;
  }

  public void setBz(String bz) {
    this.bz = bz;
  }

}

==> history-issue-common-1.0.0-20220908.055630-9-sources.jar: cn/gtmap/realestate/supervise/entity/JkAjxx.java <==
package cn.gtmap.realestate.supervise.entity;

import com.alibaba.fastjson.annotation.JSONField;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2020/5/23
 * @description 不动产登记历史遗留问题建库案件信息
 */
@Table(name = "JK_AJXX")
public class JkAjxx implements Serializable {
  @Id
  private String id; //主键
  private String ajbh; //案件编号
  private String wtdldm; //问题大类代码
  private String wtxldm; //问题小类代码
  private String xqmc;  //小区名称
  private String xqdz;  //小区地址
  private String js;  //件数
  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date yjjjsj; //预计解决时间
  private String jjcs; //解决措施
  private String jjzt; //解决状态
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date cjsj;  //创建时间
  private String cjr;  //创建人
  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date yjjbjsj; //已解决编辑时间
  private String yjjbjr; //已解决编辑人
  private String xzqdm; //行政区代码
  private String ajms; //案件描述
  private String bz; //备注

  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JSONField(format = "yyyy-MM-dd HH:mm:ss")
  private Date ajfxsj; //案件发现时间


  public String getId() {
    return id;
  }

  public void setId(String id) {
    this.id = id;
  }


  public String getAjbh() {
    return ajbh;
  }

  public void setAjbh(String ajbh) {
    this.ajbh = ajbh;
  }


  public String getWtdldm() {
    return wtdldm;
  }

  public void setWtdldm(String wtdldm) {
    this.wtdldm = wtdldm;
  }


  public String getWtxldm() {
    return wtxldm;
  }

  public void setWtxldm(String wtxldm) {
    this.wtxldm = wtxldm;
  }


  public String getXqmc() {
    return xqmc;
  }

  public void setXqmc(String xqmc) {
    this.xqmc = xqmc;
  }


  public String getXqdz() {
    return xqdz;
  }

  public void setXqdz(String xqdz) {
    this.xqdz = xqdz;
  }


  public String getJs() {
    return js;
  }

  public void setJs(String js) {
    this.js = js;
  }

  public Date getYjjjsj() {
    return yjjjsj;
  }

  public void setYjjjsj(Date yjjjsj) {
    this.yjjjsj = yjjjsj;
  }

  public String getJjcs() {
    return jjcs;
  }

  public void setJjcs(String jjcs) {
    this.jjcs = jjcs;
  }


  public String getJjzt() {
    return jjzt;
  }

  public void setJjzt(String jjzt) {
    this.jjzt = jjzt;
  }

  public Date getCjsj() {
    return cjsj;
  }

  public void setCjsj(Date cjsj) {
    this.cjsj = cjsj;
  }

  public String getCjr() {
    return cjr;
  }

  public void setCjr(String cjr) {
    this.cjr = cjr;
  }

  public Date getYjjbjsj() {
    return yjjbjsj;
  }

  public void setYjjbjsj(Date yjjbjsj) {
    this.yjjbjsj = yjjbjsj;
  }

  public String getYjjbjr() {
    return yjjbjr;
  }

  public void setYjjbjr(String yjjbjr) {
    this.yjjbjr = yjjbjr;
  }


  public String getXzqdm() {
    return xzqdm;
  }

  public void setXzqdm(String xzqdm) {
    this.xzqdm = xzqdm;
  }

  public String getAjms() {
    return ajms;
  }

  public void setAjms(String ajms) {
    this.ajms = ajms;
  }

  public String getBz() {
    return bz;
  }

  public void setBz(String bz) {
    this.bz = bz;
  }

  public Date getAjfxsj() {
    return ajfxsj;
  }

  public void setAjfxsj(Date ajfxsj) {
    this.ajfxsj = ajfxsj;
  }

}
